@@ -3,8 +3,8 @@
 ;; Copyright (C) 2016–2024 Tamas K. Papp
 ;; Author: Tamas Papp <tkpapp@gmail.com>
 ;; Keywords: languages
-;; Package-Version: 20250719.1449
-;; Package-Revision: 681efc14a72e
+;; Package-Version: 20260130.1701
+;; Package-Revision: 550e7c5e9302
 ;; Package-Requires: ((emacs "29.1")(s "1.12"))
 ;; URL: https://github.com/tpapp/julia-repl
 
@@ -53,7 +53,7 @@
 ;;
 
 (defgroup julia-repl nil
-  "A minor mode for a Julia REPL"
+  "A minor mode for a Julia REPL."
   :group 'julia)
 
 (defcustom julia-repl-inferior-buffer-name-base "julia"
@@ -86,16 +86,19 @@ Note that this affects all buffers using the ‘ansi-term’ map."
   :group 'julia-repl)
 
 (defcustom julia-repl-pop-to-buffer t
-  "When non-nil pop to julia repl"
+  "When non-nil, pop to `julia-repl'."
   :type 'symbol
   :group 'julia-repl)
 
 (defcustom julia-repl-path-rewrite-rules nil
   "A list of rewrite rules applied to paths sent with ‘include’ and similar.
 
-Each rule should be a function that is called with a path, in the given order. If the function returns ‘nil’, the next one is tried, otherwise the result is used as the rewritten path.
+Each rule should be a function that is called with a path, in the given
+order. If the function returns nil, the next one is tried, otherwise
+the result is used as the rewritten path.
 
-This can be used a workaround, usually necessary on non-Unix systems. Eg for Cygwin-based Windows, use
+This can be used a workaround, usually necessary on non-Unix systems. Eg
+for Cygwin-based Windows, use
 
    (setq julia-repl-path-rewrite-rules julia-repl-cygwin-path-rewrite-rules)
 
@@ -109,7 +112,7 @@ in your Emacs init file after loading this package."
   :group 'julia-repl)
 
 (defcustom julia-repl-set-term-escape t
-  "Set the escape char C-x globally for term. Useful for switching windows, but users who do not want this globally should set it to nil."
+  "Set the escape char \`C-x globally for term. Useful for switching windows, but users who do not want this globally should set it to nil."
   :type 'boolean
   :group 'julia-repl)
 
@@ -460,7 +463,8 @@ prevent further attempts."
   (unless (plist-member (cddr executable-record) :basedir)
     (let* ((executable-path (julia-repl--executable-path executable-record))
            (basedir (julia-repl--capture-basedir executable-path)))
-      (nconc executable-record `(:basedir ,basedir))
+      (when basedir
+        (nconc executable-record `(:basedir ,basedir)))
       (unless basedir
         (warn "could not capture basedir for Julia executable %s"
               executable-path)))))
@@ -927,7 +931,7 @@ be added."
 
 \\{julia-repl-mode-map}"
   :init-value nil
-  :lighter ">"
+  :lighter " >"
   :keymap
   `((,(kbd "C-c C-a")    . julia-repl-activate-parent)
     (,(kbd "C-c C-b")    . julia-repl-send-buffer)
